class HarambeException(Exception):
    """Base exception for all custom exceptions in Harambe."""

    pass


class SchemaValidationError(HarambeException):
    def __init__(self, message: str = None):
        super().__init__(message)


class CaptchaError(HarambeException):
    def __init__(self, message: str = "CAPTCHA was hit.") -> None:
        super().__init__(message)



from typing import Annotated

from pydantic import BeforeValidator

ParserTypeNumber = Annotated[
    float,
    BeforeValidator(
        lambda value: value.replace(",", "") if isinstance(value, str) else value
    ),
]



from typing import Any, List

from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated


class ParserTypeEnum:
    def __new__(cls, variants: list[str]) -> Any:
        return Annotated[str, AfterValidator(cls.validate_type(variants))]

    @staticmethod
    def validate_type(variants: list[str]) -> Any:
        def _validate_type(value: str) -> str:
            # Check if the value exists among variants
            if value not in variants:
                raise ValueError(
                    f'Value "{value}" doesn\'t match any of the variants ({variants})'
                )
            return value

        return _validate_type
